  CINIT(FILE, OBJECTPOINT, 1),
  CINIT(URL,  OBJECTPOINT, 2),
  CINIT(PORT, LONG, 3),
  CINIT(PROXY, OBJECTPOINT, 4),
  CINIT(USERPWD, OBJECTPOINT, 5),
  CINIT(PROXYUSERPWD, OBJECTPOINT, 6),
  CINIT(RANGE, OBJECTPOINT, 7),
  CINIT(INFILE, OBJECTPOINT, 9),
  CINIT(ERRORBUFFER, OBJECTPOINT, 10),
  CINIT(WRITEFUNCTION, FUNCTIONPOINT, 11),
  CINIT(READFUNCTION, FUNCTIONPOINT, 12),
  CINIT(TIMEOUT, LONG, 13),
  CINIT(INFILESIZE, LONG, 14),
  CINIT(POSTFIELDS, OBJECTPOINT, 15),
  CINIT(REFERER, OBJECTPOINT, 16),
  CINIT(FTPPORT, OBJECTPOINT, 17),
  CINIT(USERAGENT, OBJECTPOINT, 18),
  CINIT(LOW_SPEED_LIMIT, LONG, 19),
  CINIT(LOW_SPEED_TIME, LONG, 20),
  CINIT(RESUME_FROM, LONG, 21),
  CINIT(COOKIE, OBJECTPOINT, 22),
  CINIT(HTTPHEADER, OBJECTPOINT, 23),
  CINIT(HTTPPOST, OBJECTPOINT, 24),
  CINIT(SSLCERT, OBJECTPOINT, 25),
#ifdef HAVE_CURLOPT_KEYPASSWD
  CINIT(KEYPASSWD, OBJECTPOINT, 26),
#endif

  CINIT(CRLF, LONG, 27),
  CINIT(QUOTE, OBJECTPOINT, 28),
  CINIT(WRITEHEADER, OBJECTPOINT, 29),
  CINIT(COOKIEFILE, OBJECTPOINT, 31),
  CINIT(SSLVERSION, LONG, 32),
  CINIT(TIMECONDITION, LONG, 33),
  CINIT(TIMEVALUE, LONG, 34),
  CINIT(CUSTOMREQUEST, OBJECTPOINT, 36),
  CINIT(STDERR, OBJECTPOINT, 37),
  CINIT(POSTQUOTE, OBJECTPOINT, 39),
  CINIT(WRITEINFO, OBJECTPOINT, 40),
  CINIT(VERBOSE, LONG, 41),      /* talk a lot */
  CINIT(HEADER, LONG, 42),       /* throw the header out too */
  CINIT(NOPROGRESS, LONG, 43),   /* shut off the progress meter */
  CINIT(NOBODY, LONG, 44),       /* use HEAD to get http document */
  CINIT(FAILONERROR, LONG, 45),  /* no output on http error codes >= 300 */
  CINIT(UPLOAD, LONG, 46),       /* this is an upload */
  CINIT(POST, LONG, 47),         /* HTTP POST method */
#ifdef HAVE_CURLOPT_DIRLISTONLY
  CINIT(DIRLISTONLY, LONG, 48),  /* return bare names when listing directories */
#endif

#ifdef HAVE_CURLOPT_APPEND
  CINIT(APPEND, LONG, 50),       /* Append instead of overwrite on upload! */
#endif

  CINIT(NETRC, LONG, 51),
  CINIT(FOLLOWLOCATION, LONG, 52),  /* use Location: Luke! */
  CINIT(TRANSFERTEXT, LONG, 53), /* transfer data in text/ASCII format */
  CINIT(PUT, LONG, 54),          /* HTTP PUT */
  CINIT(PROGRESSFUNCTION, FUNCTIONPOINT, 56),
  CINIT(PROGRESSDATA, OBJECTPOINT, 57),
  CINIT(AUTOREFERER, LONG, 58),
  CINIT(PROXYPORT, LONG, 59),
  CINIT(POSTFIELDSIZE, LONG, 60),
  CINIT(HTTPPROXYTUNNEL, LONG, 61),
  CINIT(INTERFACE, OBJECTPOINT, 62),
#ifdef HAVE_CURLOPT_KRBLEVEL
  CINIT(KRBLEVEL, OBJECTPOINT, 63),
#endif

  CINIT(SSL_VERIFYPEER, LONG, 64),
  CINIT(CAINFO, OBJECTPOINT, 65),
  CINIT(MAXREDIRS, LONG, 68),
  CINIT(FILETIME, LONG, 69),
  CINIT(TELNETOPTIONS, OBJECTPOINT, 70),
  CINIT(MAXCONNECTS, LONG, 71),
  CINIT(CLOSEPOLICY, LONG, 72),
  CINIT(FRESH_CONNECT, LONG, 74),
  CINIT(FORBID_REUSE, LONG, 75),
  CINIT(RANDOM_FILE, OBJECTPOINT, 76),
  CINIT(EGDSOCKET, OBJECTPOINT, 77),
  CINIT(CONNECTTIMEOUT, LONG, 78),
  CINIT(HEADERFUNCTION, FUNCTIONPOINT, 79),
  CINIT(HTTPGET, LONG, 80),
  CINIT(SSL_VERIFYHOST, LONG, 81),
  CINIT(COOKIEJAR, OBJECTPOINT, 82),
  CINIT(SSL_CIPHER_LIST, OBJECTPOINT, 83),
  CINIT(HTTP_VERSION, LONG, 84),
  CINIT(FTP_USE_EPSV, LONG, 85),
  CINIT(SSLCERTTYPE, OBJECTPOINT, 86),
  CINIT(SSLKEY, OBJECTPOINT, 87),
  CINIT(SSLKEYTYPE, OBJECTPOINT, 88),
  CINIT(SSLENGINE, OBJECTPOINT, 89),
  CINIT(SSLENGINE_DEFAULT, LONG, 90),
  CINIT(DNS_USE_GLOBAL_CACHE, LONG, 91), /* To become OBSOLETE soon */
  CINIT(DNS_CACHE_TIMEOUT, LONG, 92),
  CINIT(PREQUOTE, OBJECTPOINT, 93),
  CINIT(DEBUGFUNCTION, FUNCTIONPOINT, 94),
  CINIT(DEBUGDATA, OBJECTPOINT, 95),
  CINIT(COOKIESESSION, LONG, 96),
  CINIT(CAPATH, OBJECTPOINT, 97),
  CINIT(BUFFERSIZE, LONG, 98),
  CINIT(NOSIGNAL, LONG, 99),
  CINIT(SHARE, OBJECTPOINT, 100),
  CINIT(PROXYTYPE, LONG, 101),
  CINIT(ENCODING, OBJECTPOINT, 102),
  CINIT(PRIVATE, OBJECTPOINT, 103),
  CINIT(HTTP200ALIASES, OBJECTPOINT, 104),
  CINIT(UNRESTRICTED_AUTH, LONG, 105),
  CINIT(FTP_USE_EPRT, LONG, 106),
  CINIT(HTTPAUTH, LONG, 107),
  CINIT(SSL_CTX_FUNCTION, FUNCTIONPOINT, 108),
  CINIT(SSL_CTX_DATA, OBJECTPOINT, 109),
  CINIT(FTP_CREATE_MISSING_DIRS, LONG, 110),
  CINIT(PROXYAUTH, LONG, 111),
  CINIT(FTP_RESPONSE_TIMEOUT, LONG, 112),
  CINIT(IPRESOLVE, LONG, 113),
  CINIT(MAXFILESIZE, LONG, 114),
  CINIT(INFILESIZE_LARGE, OFF_T, 115),
  CINIT(RESUME_FROM_LARGE, OFF_T, 116),
  CINIT(MAXFILESIZE_LARGE, OFF_T, 117),
  CINIT(NETRC_FILE, OBJECTPOINT, 118),
#ifdef HAVE_CURLOPT_USE_SSL
  CINIT(USE_SSL, LONG, 119),
#endif

  CINIT(POSTFIELDSIZE_LARGE, OFF_T, 120),
  CINIT(TCP_NODELAY, LONG, 121),
  CINIT(FTPSSLAUTH, LONG, 129),
  CINIT(IOCTLFUNCTION, FUNCTIONPOINT, 130),
  CINIT(IOCTLDATA, OBJECTPOINT, 131),
  CINIT(FTP_ACCOUNT, OBJECTPOINT, 134),
#ifdef HAVE_CURLOPT_COOKIELIST
  CINIT(COOKIELIST, OBJECTPOINT, 135),
#endif

#ifdef HAVE_CURLOPT_IGNORE_CONTENT_LENGTH
  CINIT(IGNORE_CONTENT_LENGTH, LONG, 136),
#endif

#ifdef HAVE_CURLOPT_FTP_SKIP_PASV_IP
  CINIT(FTP_SKIP_PASV_IP, LONG, 137),
#endif

#ifdef HAVE_CURLOPT_FTP_FILEMETHOD
  CINIT(FTP_FILEMETHOD, LONG, 138),
#endif

#ifdef HAVE_CURLOPT_LOCALPORT
  CINIT(LOCALPORT, LONG, 139),
#endif

#ifdef HAVE_CURLOPT_LOCALPORTRANGE
  CINIT(LOCALPORTRANGE, LONG, 140),
#endif

#ifdef HAVE_CURLOPT_CONNECT_ONLY
  CINIT(CONNECT_ONLY, LONG, 141),
#endif

#ifdef HAVE_CURLOPT_CONV_FROM_NETWORK_FUNCTION
  CINIT(CONV_FROM_NETWORK_FUNCTION, FUNCTIONPOINT, 142),
#endif

#ifdef HAVE_CURLOPT_CONV_TO_NETWORK_FUNCTION
  CINIT(CONV_TO_NETWORK_FUNCTION, FUNCTIONPOINT, 143),
#endif

#ifdef HAVE_CURLOPT_CONV_FROM_UTF8_FUNCTION
  CINIT(CONV_FROM_UTF8_FUNCTION, FUNCTIONPOINT, 144),
#endif

#ifdef HAVE_CURLOPT_MAX_SEND_SPEED_LARGE
  CINIT(MAX_SEND_SPEED_LARGE, OFF_T, 145),
#endif

#ifdef HAVE_CURLOPT_MAX_RECV_SPEED_LARGE
  CINIT(MAX_RECV_SPEED_LARGE, OFF_T, 146),
#endif

#ifdef HAVE_CURLOPT_FTP_ALTERNATIVE_TO_USER
  CINIT(FTP_ALTERNATIVE_TO_USER, OBJECTPOINT, 147),
#endif

#ifdef HAVE_CURLOPT_SOCKOPTFUNCTION
  CINIT(SOCKOPTFUNCTION, FUNCTIONPOINT, 148),
#endif

#ifdef HAVE_CURLOPT_SOCKOPTDATA
  CINIT(SOCKOPTDATA, OBJECTPOINT, 149),
#endif

#ifdef HAVE_CURLOPT_SSL_SESSIONID_CACHE
  CINIT(SSL_SESSIONID_CACHE, LONG, 150),
#endif

#ifdef HAVE_CURLOPT_SSH_AUTH_TYPES
  CINIT(SSH_AUTH_TYPES, LONG, 151),
#endif

#ifdef HAVE_CURLOPT_SSH_PUBLIC_KEYFILE
  CINIT(SSH_PUBLIC_KEYFILE, OBJECTPOINT, 152),
#endif

#ifdef HAVE_CURLOPT_SSH_PRIVATE_KEYFILE
  CINIT(SSH_PRIVATE_KEYFILE, OBJECTPOINT, 153),
#endif

#ifdef HAVE_CURLOPT_FTP_SSL_CCC
  CINIT(FTP_SSL_CCC, LONG, 154),
#endif

#ifdef HAVE_CURLOPT_TIMEOUT_MS
  CINIT(TIMEOUT_MS, LONG, 155),
#endif

#ifdef HAVE_CURLOPT_CONNECTTIMEOUT_MS
  CINIT(CONNECTTIMEOUT_MS, LONG, 156),
#endif

#ifdef HAVE_CURLOPT_HTTP_TRANSFER_DECODING
  CINIT(HTTP_TRANSFER_DECODING, LONG, 157),
#endif

#ifdef HAVE_CURLOPT_HTTP_CONTENT_DECODING
  CINIT(HTTP_CONTENT_DECODING, LONG, 158),
#endif

#ifdef HAVE_CURLOPT_NEW_FILE_PERMS
  CINIT(NEW_FILE_PERMS, LONG, 159),
#endif

#ifdef HAVE_CURLOPT_NEW_DIRECTORY_PERMS
  CINIT(NEW_DIRECTORY_PERMS, LONG, 160),
#endif

#ifdef HAVE_CURLOPT_POSTREDIR
  CINIT(POSTREDIR, LONG, 161),
#endif

#ifdef HAVE_CURLOPT_SSH_HOST_PUBLIC_KEY_MD5
  CINIT(SSH_HOST_PUBLIC_KEY_MD5, OBJECTPOINT, 162),
#endif

#ifdef HAVE_CURLOPT_OPENSOCKETFUNCTION
  CINIT(OPENSOCKETFUNCTION, FUNCTIONPOINT, 163),
#endif

#ifdef HAVE_CURLOPT_OPENSOCKETDATA
  CINIT(OPENSOCKETDATA, OBJECTPOINT, 164),
#endif

#ifdef HAVE_CURLOPT_COPYPOSTFIELDS
  CINIT(COPYPOSTFIELDS, OBJECTPOINT, 165),
#endif

#ifdef HAVE_CURLOPT_PROXY_TRANSFER_MODE
  CINIT(PROXY_TRANSFER_MODE, LONG, 166),
#endif

#ifdef HAVE_CURLOPT_SEEKFUNCTION
  CINIT(SEEKFUNCTION, FUNCTIONPOINT, 167),
#endif

#ifdef HAVE_CURLOPT_SEEKDATA
  CINIT(SEEKDATA, OBJECTPOINT, 168),
#endif

#ifdef HAVE_CURLOPT_CRLFILE
  CINIT(CRLFILE, OBJECTPOINT, 169),
#endif

#ifdef HAVE_CURLOPT_ISSUERCERT
  CINIT(ISSUERCERT, OBJECTPOINT, 170),
#endif

#ifdef HAVE_CURLOPT_ADDRESS_SCOPE
  CINIT(ADDRESS_SCOPE, LONG, 171),
#endif

#ifdef HAVE_CURLOPT_CERTINFO
  CINIT(CERTINFO, LONG, 172),
#endif

#ifdef HAVE_CURLOPT_USERNAME
  CINIT(USERNAME, OBJECTPOINT, 173),
#endif

#ifdef HAVE_CURLOPT_PASSWORD
  CINIT(PASSWORD, OBJECTPOINT, 174),
#endif

#ifdef HAVE_CURLOPT_PROXYUSERNAME
  CINIT(PROXYUSERNAME, OBJECTPOINT, 175),
#endif

#ifdef HAVE_CURLOPT_PROXYPASSWORD
  CINIT(PROXYPASSWORD, OBJECTPOINT, 176),
#endif

#ifdef HAVE_CURLOPT_NOPROXY
  CINIT(NOPROXY, OBJECTPOINT, 177),
#endif

#ifdef HAVE_CURLOPT_TFTP_BLKSIZE
  CINIT(TFTP_BLKSIZE, LONG, 178),
#endif

#ifdef HAVE_CURLOPT_SOCKS5_GSSAPI_SERVICE
  CINIT(SOCKS5_GSSAPI_SERVICE, LONG, 179),
#endif

#ifdef HAVE_CURLOPT_SOCKS5_GSSAPI_NEC
  CINIT(SOCKS5_GSSAPI_NEC, LONG, 180),
#endif

#ifdef HAVE_CURLOPT_PROTOCOLS
  CINIT(PROTOCOLS, LONG, 181),
#endif

#ifdef HAVE_CURLOPT_REDIR_PROTOCOLS
  CINIT(REDIR_PROTOCOLS, LONG, 182),
#endif

#ifdef HAVE_CURLOPT_WRITEDATA
{ "WRITEDATA", CURLOPT_FILE},
#endif

#ifdef CURLOPT_POST301
{ "POST301", CURLOPT_POSTREDIR},
#endif

#ifdef CURLOPT_FTP_SSL
{ "FTP_SSL", CURLOPT_USE_SSL},
#endif

#ifdef CURLOPT_KRB4LEVEL
{ "KRB4LEVEL", CURLOPT_KRBLEVEL},
#endif

#ifdef CURLOPT_HEADERDATA
{ "HEADERDATA", CURLOPT_WRITEHEADER},
#endif

#ifdef CURLOPT_SSLKEYPASSWD
{ "SSLKEYPASSWD", CURLOPT_KEYPASSWD},
#endif

#ifdef CURLOPT_FTPAPPEND
{ "FTPAPPEND", CURLOPT_APPEND},
#endif

#ifdef CURLOPT_SSLCERTPASSWD
{ "SSLCERTPASSWD", CURLOPT_KEYPASSWD},
#endif

#ifdef CURLOPT_READDATA
{ "READDATA", CURLOPT_INFILE},
#endif

#ifdef CURLOPT_FTPLISTONLY
{ "FTPLISTONLY", CURLOPT_DIRLISTONLY}
#endif

